<?php

/**
 * Public Class QrReview
 * Store informations about all sended SMS with a review and her dates (SMS+review)
 *
 * PHP version 5
 *
 * Copyright © 2013 Mélissa Djebel
 *
 * This file is part of Galette (http://galette.tuxfamily.org).
 *
 * Plugin ObjectsLend is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Galette. If not, see <http://www.gnu.org/licenses/>.
 *
 * @category  Plugins
 * @package   QR Code
 *
 * @author    Mélissa Djebel <melissa.djebel@gmx.net>
 * @copyright 2013 Mélissa Djebel
 * @license   http://www.gnu.org/licenses/gpl-3.0.html GPL License 3.0 or (at your option) any later version
 * @version   0.2.0
 * @link      http://galette.tuxfamily.org
 * @since     Available since 0.7
 */
class QrReview {

    const TABLE = 'review';
    const PK = 'review_id';

    private $_fields = array(
        '_review_id' => 'int',
        '_mobile' => 'varchar(20)',
        '_sms_date' => 'datetime',
        '_adherent_id' => 'int',
        '_message' => 'varchar(160)',
        '_review' => 'varchar(400)',
        '_review_date' => 'datetime'
    );
    private $_review_id;
    private $_mobile;
    private $_sms_date;
    private $_adherent_id;
    private $_message;
    private $_review;
    private $_review_date;
    // Pour affichage dans la liste
    private $_nom_adh;
    private $_prenom_adh;
    private $_pseudo_adh;

    public function __construct($args = null) {
        global $zdb;

        $this->_sms_date = date('Y-m-d H:i:s');

        if (is_int($args)) {
            try {
                $select = new Zend_Db_Select($zdb->db);
                $select->from(PREFIX_DB . QR_PREFIX . self::TABLE)
                        ->where(self::PK . ' = ' . $args);
                if ($select->query()->rowCount() == 1) {
                    $this->_loadFromRS($select->query()->fetch());
                }
            } catch (Exception $e) {
                Analog\Analog::log(
                        'Something went wrong :\'( | ' . $e->getMessage() . "\n" .
                        $e->getTraceAsString(), Analog\Analog::ERROR
                );
            }
        } else if (is_object($args)) {
            $this->_loadFromRS($args);
        }
    }

    /**
     * Populate object from a resultset row
     *
     * @param ResultSet $r the resultset row
     *
     * @return void
     */
    private function _loadFromRS($r) {
        $this->_review_id = $r->review_id;
        $this->_mobile = $r->mobile;
        $this->_sms_date = $r->sms_date;
        $this->_adherent_id = $r->adherent_id;
        $this->_message = $r->message;
        $this->_review = $r->review;
        $this->_review_date = $r->review_date;
    }

    /**
     * Enregistre l'élément en cours que ce soit en insert ou update
     * 
     * @return bool False si l'enregistrement a échoué, true si aucune erreur
     */
    public function store() {
        global $zdb;

        try {
            $values = array();

            if (strlen($this->_review) > 0 && ($this->_review_date == null || $this->_review_date == '')) {
                $this->_review_date = date('Y-m-d H:i:s');
            }

            foreach ($this->_fields as $k => $v) {
                $values[substr($k, 1)] = $this->$k;
            }

            if (!isset($this->_review_id) || $this->_review_id == '') {
                $add = $zdb->db->insert(PREFIX_DB . QR_PREFIX . self::TABLE, $values);
                if ($add > 0) {
                    $this->_review_id = $zdb->db->lastInsertId();
                } else {
                    throw new Exception(_T("QR REVIEW.AJOUT ECHEC"));
                }
            } else {
                $edit = $zdb->db->update(
                        PREFIX_DB . QR_PREFIX . self::TABLE, $values, self::PK . '=' . $this->_review_id
                );
            }
            return true;
        } catch (Exception $e) {
            Analog\Analog::log(
                    'Something went wrong :\'( | ' . $e->getMessage() . "\n" .
                    $e->getTraceAsString(), Analog\Analog::ERROR
            );
            return false;
        }
    }

    /**
     * Renvoi les 50 derniers reviews stockés en base triés par leur date
     * de création (en ordre inverse, plus récent en 1er)
     * 
     * @return boolean|QrReview[] tableau de 50 QrReview maximum
     */
    public static function getAll() {
        global $zdb;

        try {
            $select = new Zend_Db_Select($zdb->db);
            $select->from(PREFIX_DB . QR_PREFIX . self::TABLE)
                    ->join(PREFIX_DB . \Galette\Entity\Adherent::TABLE, PREFIX_DB . QR_PREFIX . self::TABLE . '.adherent_id = ' . PREFIX_DB . \Galette\Entity\Adherent::TABLE . '.id_adh')
                    ->order('sms_date desc')
                    ->limitPage(0, 50);

            $rows = $select->query()->fetchAll();
            $results = array();
            foreach ($rows as $r) {
                $review = new QrReview($r);
                $review->nom_adh = $r->nom_adh;
                $review->prenom_adh = $r->prenom_adh;
                $review->pseudo_adh = $r->pseudo_adh;
                $results[] = $review;
            }

            return $results;
        } catch (Exception $e) {
            Analog\Analog::log(
                    'Something went wrong :\'( | ' . $e->getMessage() . "\n" .
                    $e->getTraceAsString(), Analog\Analog::ERROR
            );
            return false;
        }
    }

    /**
     * Global getter method
     *
     * @param string $name name of the property we want to retrive
     *
     * @return false|object the called property
     */
    public function __get($name) {
        $rname = '_' . $name;
        if (substr($rname, 0, 3) == '___') {
            return false;
        }
        switch ($name) {
            case 'sms_date_gui':
                $dt = new DateTime($this->_sms_date);
                return $dt->format('D j M à H:i');
            case 'review_date_gui':
                if ($this->_review_date != null && $this->_review_date != '') {
                    $dt = new DateTime($this->_review_date);
                    return $dt->format('D j M à H:i');
                } else {
                    return '';
                }
            default:
                return $this->$rname;
        }
    }

    /**
     * Global setter method
     *
     * @param string $name  name of the property we want to assign a value to
     * @param object $value a relevant value for the property
     *
     * @return void
     */
    public function __set($name, $value) {
        $rname = '_' . $name;
        $this->$rname = $value;
    }

}

?>
